Module status_types

Module status_types 

Module for the types of the usage status that is returned by the status command

Structs

ConsideredFile
A single considered file with the EditorConfig properties which apply to it. If property has no (valid) value for the file, the respective field is None. Furthermore, if a property is disabled (= false) in the given editorconfig_args, it is always None.
ConsideredFiles
List of files considered based on the target(s) and the editorconfig_args. You can access the single ConsideredFile instances via ConsideredFiles::files.
EditorConfigFiles
List of paths to relevant .editorconfig files for the target(s). You can consider the single paths via EditorConfigFiles::paths.
StatusInfo
Status information which is the return value of the status command.

Traits

StatusTexts
Trait for the text representation of StatusInfo and its sub structs